Internal implementation details for hyperdb-api.
This crate is not a public API. Use hyperdb-api directly. The items
exposed here may change between any two releases, including patch releases,
without semver deprecation.
Organization
Modules
- client
- Client library for Hyper database.
- protocol
- Wire protocol implementation for Hyper database.
- types
- Type conversions for Hyper database using LittleEndian (HyperBinary) format.
Macros
- params
- Macro for building prepared statement parameters with automatic encoding.