PreparedStatement

Struct PreparedStatement 

pub struct PreparedStatement { /* private fields */ }
A prepared statement.

Prepared statements allow you to execute the same query multiple times with different parameters efficiently. The statement is prepared once on the server and can be executed many times with different parameter values.

For automatic cleanup, use [OwnedPreparedStatement] via [crate::Client::prepare].

Example

let stmt = client.prepare("SELECT * FROM users WHERE id = $1")?;
let rows1 = client.execute(&stmt, params![42_i32])?;
let rows2 = client.execute(&stmt, params![100_i32])?;

Implementations

Source

impl PreparedStatement

pub fn name(&self) -> &str

Returns the statement name.

pub fn query(&self) -> &str

Returns the original query.

pub fn param_types(&self) -> &[Oid]

Returns the parameter types.

pub fn param_count(&self) -> usize

Returns the number of parameters.

pub fn columns(&self) -> &[Column]

Returns the result column descriptions.

pub fn column_count(&self) -> usize

Returns the number of result columns.