pub struct RowDescriptionBody { /* private fields */ }Expand description
Row description body.
Sent in response to a Describe or Execute message, describing the columns that will be returned by a query. Each field description includes name, type OID, format, and other metadata.
Implementations