Crate hyperdb_api_core

Crate hyperdb_api_core 

Internal implementation details for hyperdb-api.

This crate is not a public API. Use hyperdb-api directly. The items exposed here may change between any two releases, including patch releases, without semver deprecation.

Organization

  • types — SQL type system, binary encoding, OIDs (ex-hyper-types)
  • protocolPostgreSQL wire protocol messages, HyperBinary COPY format (ex-hyper-protocol)
  • client — Sync/async TCP and gRPC clients, auth, TLS (ex-hyper-client)

Modules

client
Client library for Hyper database.
protocol
Wire protocol implementation for Hyper database.
types
Type conversions for Hyper database using LittleEndian (HyperBinary) format.

Macros

params
Macro for building prepared statement parameters with automatic encoding.