pub struct PreparedStatement { /* private fields */ }Expand description
A prepared statement.
Prepared statements allow you to execute the same query multiple times with different parameters efficiently. The statement is prepared once on the server and can be executed many times with different parameter values.
For automatic cleanup, use [OwnedPreparedStatement] via [crate::Client::prepare].
Example
let stmt = client.prepare("SELECT * FROM users WHERE id = $1")?;
let rows1 = client.execute(&stmt, params![42_i32])?;
let rows2 = client.execute(&stmt, params![100_i32])?;Implementations
Sourceimpl PreparedStatement
impl PreparedStatement
Sourcepub fn param_types(&self) -> &[Oid]
pub fn param_types(&self) -> &[Oid]
Returns the parameter types.
Sourcepub fn param_count(&self) -> usize
pub fn param_count(&self) -> usize
Returns the number of parameters.
Sourcepub fn column_count(&self) -> usize
pub fn column_count(&self) -> usize
Returns the number of result columns.