pub fn sync(buf: &mut BytesMut)
Writes a sync message.
Forces the server to process all pending messages and respond with ReadyForQuery. Should be sent after completing a query sequence (Parse/Bind/Execute).
ReadyForQuery